@@ -15,9 +15,9 @@ It also provides some platform-specific functions (most notably getting
 the path of the application bundle on OSX). Supported operating
 systems:
  
- * Win32 (tested on Windows XP \/ x86 only)
+ * Win32 (tested on Windows 7)
  
- * Mac OS X (tested on Leopard \/ x86 only)
+ * Mac OS X
  
  * Linux
 
